@@ -3,8 +3,8 @@
 # This file is part of pyasn1-modules software.
 #
 # Created by Stanisław Pitucha with asn1ate tool.
-# Copyright (c) 2005-2017, Ilya Etingof <etingof@gmail.com>
-# License: http://pyasn1.sf.net/license.html
+# Copyright (c) 2005-2019, Ilya Etingof <etingof@gmail.com>
+# License: http://snmplabs.com/pyasn1/license.html
 #
 # Cryptographic Message Syntax (CMS)
 #
@@ -21,7 +21,7 @@ from pyasn1.type import useful
 from pyasn1_modules import rfc3281
 from pyasn1_modules import rfc5280
 
-MAX = 64
+MAX = float('inf')
 
 
 def _buildOid(*components):
